summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_view.h')
-rw-r--r--kspread/kspread_view.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kspread/kspread_view.h b/kspread/kspread_view.h
index f9ce1bdd..2dfecfa5 100644
--- a/kspread/kspread_view.h
+++ b/kspread/kspread_view.h
@@ -253,22 +253,22 @@ public:
/**
*
* @param _geometry is the zoomed geometry of the new child.
* @param _entry is the entry to insert.
*
* @todo check validity of @p _entry docs.
*/
- void insertChart( const TQRect& _geometry, KoDocumentEntry& _entry );
+ void insertChart( const TQRect& _tqgeometry, KoDocumentEntry& _entry );
/**
*
* @param _geometry is the geometry of the new child.
* @param _entry is the entry to insert.
*
* @todo check validity of @p _entry docs.
*/
- void insertChild( const TQRect& _geometry, KoDocumentEntry& _entry );
+ void insertChild( const TQRect& _tqgeometry, KoDocumentEntry& _entry );
- // void insertPicture( const TQRect& _geometry, KURL& _file );
+ // void insertPicture( const TQRect& _tqgeometry, KURL& _file );
virtual void print( KPrinter &printer );
virtual void setupPrinter( KPrinter &printer );
@@ -321,7 +321,7 @@ public:
void updateShowSheetMenu();
/**
- * Mark all selected cells / regions of cells as 'dirty' (ie. requiring a repaint)
+ * Mark all selected cells / regions of cells as 'dirty' (ie. requiring a tqrepaint)
* They will be repainted on the next call to paintUpdates()
*/
void markSelectionAsDirty();
@@ -253,22 +253,22 @@ public:
/**
*
- * @param _geometry is the zoomed geometry of the new child.
+ * @param _tqgeometry is the zoomed tqgeometry of the new child.
* @param _entry is the entry to insert.
*
@@ -253,22 +253,22 @@ public:
/**
*
- * @param _geometry is the geometry of the new child.
+ * @param _tqgeometry is the tqgeometry of the new child.
* @param _entry is the entry to insert.
*